@@ -3,96 +3,97 @@ from easydict import EasyDict as edict
 import requests
 import json
 
-url = 'https://dbhub.herokuapp.com/'
-
-
-def get_database(api_key):
-    return DbHub(api_key)
+url = 'https://dbhub-py.herokuapp.com/'
 
 
 class DbHub:
-    def __init__(self, api_key):
-        self.api_key = api_key
+    def __init__(self, token, db_name):
+        self.token = token
+        self.db_name = db_name
+        self.collections = []
 
     def get_collection(self, collection_name):
-        return Collection(self.api_key, collection_name)
+        collection = Collection(self.token, self.db_name, collection_name)
+        self.collections.append(collection)
+        return collection
 
 
 class Collection:
-    def __init__(self, api_key, collection_name):
-        self.__api_key__ = api_key
-        self.__collection_name__ = collection_name
+    def __init__(self, token, db_name, collection_name):
+        self.__headers = {"Authorization": "Bearer %s" % token}
+        self.__db_name = db_name
+        self.__collection_name = collection_name
         self.__dict = self.__list()
 
     def __create(self, doc_id, doc):
-        doc_dict = doc if isinstance(doc, dict) else dict(doc.__dict__)
+        doc_dict = to_dict(doc)
         data = {
-            'secret': self.__api_key__,
-            'collectionName': self.__collection_name__,
-            'doc': doc_dict
+            'db_name': self.__db_name,
+            'collection_name': self.__collection_name,
+            'data': doc_dict
         }
         if doc_id:
-            data['id'] = doc_id
+            data['doc_id'] = doc_id
 
-        response = requests.post(url, json=data)
+        response = requests.post(url, json=data, headers=self.__headers)
         parsed_data = json.loads(response.text)
-        return parsed_data if not hasattr(parsed_data, 'Error') else None
+        return parsed_data
 
     def __read(self, key):
         params = {
-            'secret': self.__api_key__,
-            'collectionName': self.__collection_name__,
-            'id': key
+            'db_name': self.__db_name,
+            'collection_name': self.__collection_name,
+            'doc_id': key
         }
-        response = requests.get(url, params=params)
+        response = requests.get(url, params=params, headers=self.__headers)
         parsed_data = edict(json.loads(response.text))
-        return parsed_data if not hasattr(parsed_data, 'Error') else None
+        return parsed_data
 
     def __list(self):
         params = {
-            'secret': self.__api_key__,
-            'collectionName': self.__collection_name__
+            'db_name': self.__db_name,
+            'collection_name': self.__collection_name
         }
-        response = requests.get(url + 'list', params=params)
-        array = json.loads(response.text)
-        if hasattr(array, 'Error'):
-            return None
+        response = requests.get(url + 'list', params=params, headers=self.__headers)
+        response_dict = json.loads(response.text)
+
+        parsed_data = {}
+        for key, value in response_dict.items():
+            parsed_data[key] = edict(value)
 
-        response_dict = {}
-        for elem in array:
-            key = elem[0]
-            value = edict(elem[1])
-            response_dict[key] = value
         return response_dict
 
     def __update(self, key, doc):
+        doc_dict = to_dict(doc)
+
         data = {
-            'secret': self.__api_key__,
-            'collectionName': self.__collection_name__,
-            'id': key,
-            'doc': doc
+            'db_name': self.__db_name,
+            'collection_name': self.__collection_name,
+            'doc_id': key,
+            'data': doc_dict
         }
-        response = requests.patch(url, json=data)
+        response = requests.patch(url, json=data, headers=self.__headers)
         parsed_data = json.loads(response.text)
-        return parsed_data if not hasattr(parsed_data, 'Error') else None
+        return parsed_data
 
     def __delete(self, key):
         data = {
-            'secret': self.__api_key__,
-            'collectionName': self.__collection_name__,
-            'id': key
+            'db_name': self.__db_name,
+            'collection_name': self.__collection_name,
+            'doc_id': key
         }
-        response = requests.delete(url, params=data)
+        response = requests.delete(url, params=data, headers=self.__headers)
         parsed_data = json.loads(response.text)
-        return parsed_data if not hasattr(parsed_data, 'Error') else None
+        return parsed_data
 
     # dict imitation
 
     def __setitem__(self, key, item):
         real_key = str(key)
+        self.__dict[real_key] = item
         result = self.__create(real_key, item)
         if result:
-            self.__dict[real_key] = item
+            return
         else:
             raise Exception('Element with key [%s] was not added into the collection' % real_key)
 
@@ -171,6 +172,22 @@ class Collection:
         return str(repr(self.__dict))
 
 
-class obj:
-    def __init__(self, dict_data):
-        self.__dict__.update(dict_data)
+def to_dict(obj, class_key=None):
+    if isinstance(obj, dict):
+        data = {}
+        for (k, v) in obj.items():
+            data[k] = to_dict(v, class_key)
+        return data
+    elif hasattr(obj, "_ast"):
+        return to_dict(obj._ast())
+    elif hasattr(obj, "__iter__") and not isinstance(obj, str):
+        return [to_dict(v, class_key) for v in obj]
+    elif hasattr(obj, "__dict__"):
+        data = dict([(key, to_dict(value, class_key))
+                     for key, value in obj.__dict__.items()
+                     if not callable(value) and not key.startswith('_')])
+        if class_key is not None and hasattr(obj, "__class__"):
+            data[class_key] = obj.__class__.__name__
+        return data
+    else:
+        return obj
